Class: Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAllGidsPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAllGidsPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:custom_field_gid_value_contains_all_gids? function
Constant Summary collapse
- FUNCTION_NAME =
:custom_field_gid_value_contains_all_gids?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param
resource. - #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
@param resource
@param custom_field_gid
@param custom_field_values_gids
200 201 202 203 204 205 206 207 208 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 200 def evaluate(resource, custom_field_gid, custom_field_values_gids) actual_custom_field_values_gids = custom_fields.resource_custom_field_values_gids_or_raise(resource, custom_field_gid) custom_field_values_gids.all? do |custom_field_value| actual_custom_field_values_gids.include?(custom_field_value) end end |
#evaluate_arg?(_index) ⇒ Boolean
192 193 194 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 192 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
188 189 190 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 188 def matches? fn?(selector, FUNCTION_NAME) end |