Class: Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAnyGidPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAnyGidPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:custom_field_gid_value_contains_any_gid? function
Constant Summary collapse
- FUNCTION_NAME =
:custom_field_gid_value_contains_any_gid?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param
resource. - #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
@param resource
@param custom_field_gid
@param custom_field_values_gids
151 152 153 154 155 156 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 151 def evaluate(resource, custom_field_gid, custom_field_values_gids) actual_custom_field_values_gids = custom_fields.resource_custom_field_values_gids_or_raise(resource, custom_field_gid) actual_custom_field_values_gids.intersect?(custom_field_values_gids) end |
#evaluate_arg?(_index) ⇒ Boolean
143 144 145 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 143 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
139 140 141 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 139 def matches? fn?(selector, FUNCTION_NAME) end |