Class: Checkoff::SelectorClasses::Common::EqualsPFunctionEvaluator

Inherits:
FunctionEvaluator show all
Defined in:
lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs

Overview

:equals? function

Constant Summary collapse

FUNCTION_NAME =
:equals?

Instance Attribute Summary

Attributes inherited from FunctionEvaluator

#custom_fields, #selector

Instance Method Summary collapse

Methods inherited from FunctionEvaluator

#initialize

Methods inherited from FunctionEvaluator

#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn

Methods included from Logging

#debug, #error, #finer, #info, #log_level, #logger, #warn

Constructor Details

This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator

Instance Method Details

#evaluate(_resource, lhs, rhs) ⇒ Boolean

sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param _resource

@param lhs

@param rhs



86
87
88
# File 'lib/checkoff/internal/selector_classes/common.rb', line 86

def evaluate(_resource, lhs, rhs)
  lhs == rhs
end

#matches? ⇒ Boolean



78
79
80
# File 'lib/checkoff/internal/selector_classes/common.rb', line 78

def matches?
  fn?(selector, FUNCTION_NAME)
end