Class: Checkoff::SelectorClasses::Common::NameStartsWithPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::NameStartsWithPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:name_starts_with? function
Constant Summary collapse
- FUNCTION_NAME =
:name_starts_with?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(resource, prefix) ⇒ boolish
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project sord warn - boolish is probably not a type, but using anyway sord warn - boolish wasn't able to be resolved to a constant in this project @sg-ignore Checkoff::SelectorClasses::Common::NameStartsWithPFunctionEvaluator#evaluate return type could not be inferred.
- #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(resource, prefix) ⇒ boolish
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project sord warn - boolish is probably not a type, but using anyway sord warn - boolish wasn't able to be resolved to a constant in this project @sg-ignore Checkoff::SelectorClasses::Common::NameStartsWithPFunctionEvaluator#evaluate return type could not be inferred
@param resource
@param prefix
228 229 230 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 228 def evaluate(resource, prefix) resource.name&.start_with?(prefix) end |
#evaluate_arg?(_index) ⇒ Boolean
219 220 221 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 219 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
215 216 217 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 215 def matches? fn?(selector, FUNCTION_NAME) end |