Class: Checkoff::SelectorClasses::Common::NilPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::NilPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:nil? function
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(_resource, subvalue) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param
_resource. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(_resource, subvalue) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
@param _resource
@param subvalue
69 70 71 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 69 def evaluate(_resource, subvalue) subvalue.nil? end |
#matches? ⇒ Boolean
62 63 64 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 62 def matches? fn?(selector, :nil?) end |