Class: Checkoff::SelectorClasses::Common::NotFunctionEvaluator

Inherits:
FunctionEvaluator show all
Defined in:
lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs

Overview

:not function

Constant Summary collapse

FUNCTION_NAME =

Returns:

  • (Object)
:not

Instance Attribute Summary

Attributes inherited from FunctionEvaluator

#selector

Instance Method Summary collapse

Methods inherited from FunctionEvaluator

#initialize

Methods inherited from FunctionEvaluator

#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn

Methods included from Logging

#debug, #error, #finer, #info, #log_level, #logger, #warn

Constructor Details

This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator

Instance Method Details

#evaluate(_resource, subvalue) ⇒ Boolean

sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param _resource

@param subvalue

Parameters:

  • _resource (Asana::Resources::Task, Asana::Resources::Project)
  • subvalue (Object)

Returns:

  • (Boolean)


55
56
57
# File 'lib/checkoff/internal/selector_classes/common.rb', line 55

def evaluate(_resource, subvalue)
  !subvalue
end

#matches?Boolean

Returns:

  • (Boolean)


48
49
50
# File 'lib/checkoff/internal/selector_classes/common.rb', line 48

def matches?
  fn?(selector, FUNCTION_NAME)
end