Class: Checkoff::SelectorClasses::Common::OrFunctionEvaluator

Inherits:
FunctionEvaluator show all
Defined in:
lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs

Overview

:or function

Does not yet shortcut, but may in future - be careful with side effects!

Constant Summary collapse

FUNCTION_NAME =

Returns:

  • (Object)
:or

Instance Attribute Summary

Attributes inherited from FunctionEvaluator

#selector

Instance Method Summary collapse

Methods inherited from FunctionEvaluator

#initialize

Methods inherited from FunctionEvaluator

#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn

Methods included from Logging

#debug, #error, #finer, #info, #log_level, #logger, #warn

Constructor Details

This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator

Instance Method Details

#evaluate(_resource, *args) ⇒ Boolean

sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param _resource

@param args

Parameters:

  • _resource (Asana::Resources::Task, Asana::Resources::Project)
  • args (::Array[Object])

Returns:

  • (Boolean)


39
40
41
# File 'lib/checkoff/internal/selector_classes/common.rb', line 39

def evaluate(_resource, *args)
  args.any? { |arg| arg }
end

#matches?Boolean

Returns:

  • (Boolean)


32
33
34
# File 'lib/checkoff/internal/selector_classes/common.rb', line 32

def matches?
  fn?(selector, FUNCTION_NAME)
end