Class: Checkoff::SelectorClasses::Common::StringLiteralEvaluator

Inherits:
FunctionEvaluator show all
Defined in:
lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs

Overview

String literals

Instance Attribute Summary

Attributes inherited from FunctionEvaluator

#selector

Instance Method Summary collapse

Methods inherited from FunctionEvaluator

#initialize

Methods inherited from FunctionEvaluator

#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn

Methods included from Logging

#debug, #error, #finer, #info, #log_level, #logger, #warn

Constructor Details

This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator

Instance Method Details

#evaluate(_resource) ⇒ String

sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @sg-ignore

@param _resource

Parameters:

  • _resource (Asana::Resources::Task, Asana::Resources::Project)

Returns:

  • (String)


262
263
264
# File 'lib/checkoff/internal/selector_classes/common.rb', line 262

def evaluate(_resource)
  T.cast(selector, String)
end

#matches?Boolean

Returns:

  • (Boolean)


255
256
257
# File 'lib/checkoff/internal/selector_classes/common.rb', line 255

def matches?
  selector.is_a?(String)
end