Class: Checkoff::SelectorClasses::Project::DueDateFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Project::DueDateFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/project.rb,
sig/checkoff.rbs
Overview
:due_date function
Constant Summary collapse
- FUNCTION_NAME =
:due_date
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(resource) ⇒ String?
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @sg-ignore.
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Project::FunctionEvaluator
Instance Method Details
#evaluate(resource) ⇒ String?
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @sg-ignore
@param resource
21 22 23 |
# File 'lib/checkoff/internal/selector_classes/project.rb', line 21 def evaluate(resource) resource.due_date end |
#matches? ⇒ Boolean
14 15 16 |
# File 'lib/checkoff/internal/selector_classes/project.rb', line 14 def matches? fn?(selector, FUNCTION_NAME) end |