Class: Checkoff::SelectorClasses::Project::ReadyPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Project::ReadyPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/project.rb,
sig/checkoff.rbs
Overview
:ready? function
Constant Summary collapse
- FUNCTION_NAME =
:ready?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(project, period = :now_or_before) ⇒ Boolean
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @sg-ignore.
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Project::FunctionEvaluator
Instance Method Details
#evaluate(project, period = :now_or_before) ⇒ Boolean
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @sg-ignore
@param project
@param period — - :now_or_before or :this_week
38 39 40 41 |
# File 'lib/checkoff/internal/selector_classes/project.rb', line 38 def evaluate(project, period = :now_or_before) # @sg-ignore @projects.project_ready?(project, period:) end |
#matches? ⇒ Boolean
30 31 32 |
# File 'lib/checkoff/internal/selector_classes/project.rb', line 30 def matches? fn?(selector, FUNCTION_NAME) end |