Class: Checkoff::SelectorClasses::Section::FunctionEvaluator

Inherits:
FunctionEvaluator show all
Defined in:
lib/checkoff/internal/selector_classes/section/function_evaluator.rb,
sig/checkoff.rbs

Overview

Base class to evaluate a project selector function given fully evaluated arguments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from FunctionEvaluator

#debug, #error, #evaluate, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #matches?, #warn

Methods included from Logging

#debug, #error, #finer, #info, #log_level, #logger, #warn

Constructor Details

#initialize(selector:, sections:, client:, **kwargs) ⇒ Object

sord warn - Asana::Client wasn't able to be resolved to a constant in this project @param selector

@param client

@param sections

@param kwargs



15
16
17
18
19
20
21
22
23
# File 'lib/checkoff/internal/selector_classes/section/function_evaluator.rb', line 15

def initialize(selector:,
               sections:,
               client:,
               **kwargs)
  @selector = selector
  @sections = sections
  @client = client
  super()
end

Instance Attribute Details

#clientAsana::Client (readonly)

sord warn - Asana::Client wasn't able to be resolved to a constant in this project

Returns:

  • (Asana::Client)


31
32
33
# File 'lib/checkoff/internal/selector_classes/section/function_evaluator.rb', line 31

def client
  @client
end

#selectorArray(Symbol, Array) (readonly)

Returns:

  • (Array(Symbol, Array))


28
29
30
# File 'lib/checkoff/internal/selector_classes/section/function_evaluator.rb', line 28

def selector
  @selector
end