Class: Checkoff::SelectorClasses::Section::HasTasksPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Section::HasTasksPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/section.rb,
sig/checkoff.rbs
Overview
:has_tasks? function
Constant Summary collapse
- FUNCTION_NAME =
:has_tasks?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(section) ⇒ Boolean
sord warn - Asana::Resources::Section wasn't able to be resolved to a constant in this project @sg-ignore.
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Section::FunctionEvaluator
Instance Method Details
#evaluate(section) ⇒ Boolean
sord warn - Asana::Resources::Section wasn't able to be resolved to a constant in this project @sg-ignore
@param section
42 43 44 45 |
# File 'lib/checkoff/internal/selector_classes/section.rb', line 42 def evaluate(section) # @sg-ignore @sections.tasks_by_section_gid(section.gid).any? end |
#matches? ⇒ Boolean
34 35 36 |
# File 'lib/checkoff/internal/selector_classes/section.rb', line 34 def matches? fn?(selector, FUNCTION_NAME) end |