Class: Checkoff::SelectorClasses::Task::DependentOnPreviousSectionLastMilestonePFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::DependentOnPreviousSectionLastMilestonePFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:dependent_on_previous_section_last_milestone?
Constant Summary collapse
- FUNCTION_NAME =
:dependent_on_previous_section_last_milestone?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task, limit_to_portfolio_gid: nil) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @param
task. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task, limit_to_portfolio_gid: nil) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
@param task
@param limit_to_portfolio_gid — If specified, only projects in this portfolio will be evaluated.
305 306 307 308 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 305 def evaluate(task, limit_to_portfolio_gid: nil) timelines.task_dependent_on_previous_section_last_milestone?(task, limit_to_portfolio_gid:) end |
#matches? ⇒ Boolean
296 297 298 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 296 def matches? fn?(selector, FUNCTION_NAME) end |