Class: Checkoff::SelectorClasses::Task::InPeriodPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::InPeriodPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:in_period? function
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task, field_name, period) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @param
task. -
#evaluate_arg?(_index) ⇒ Boolean
@param
_index. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task, field_name, period) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
@param task
@param field_name — See Checksoff::Tasks#in_period?
@param period — See Checkoff::Timing#in_period?
180 181 182 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 180 def evaluate(task, field_name, period) tasks.in_period?(task, field_name, period) end |
#evaluate_arg?(_index) ⇒ Boolean
@param _index
172 173 174 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 172 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
167 168 169 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 167 def matches? fn?(selector, :in_period?) end |