Class: Checkoff::SelectorClasses::Task::InPortfolioNamedPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::InPortfolioNamedPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:in_portfolio_named? function
Constant Summary collapse
- FUNCTION_NAME =
:in_portfolio_named?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task, portfolio_name) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @param
task. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task, portfolio_name) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
@param task
@param portfolio_name
323 324 325 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 323 def evaluate(task, portfolio_name) tasks.in_portfolio_named?(task, portfolio_name) end |
#matches? ⇒ Boolean
315 316 317 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 315 def matches? fn?(selector, FUNCTION_NAME) end |