Class: Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:milestone? function
Constant Summary collapse
- FUNCTION_NAME =
:milestone?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator#evaluate return type could not be inferred.
- #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator#evaluate return type could not be inferred
@param task
391 392 393 394 395 396 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 391 def evaluate(task) resource_subtype = task.resource_subtype raise 'Please add resource_subtype to extra_fields' if resource_subtype.nil? resource_subtype == 'milestone' end |
#evaluate_arg?(_index) ⇒ Boolean
382 383 384 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 382 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
378 379 380 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 378 def matches? fn?(selector, FUNCTION_NAME) end |