Class: Checkoff::SelectorClasses::Task::UnassignedPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::UnassignedPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:unassigned? function
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @param
task. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #initialize, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
@param task
201 202 203 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 201 def evaluate(task) task.assignee.nil? end |
#matches? ⇒ Boolean
195 196 197 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 195 def matches? fn?(selector, :unassigned?) end |