Class: Checkoff::SectionSelectorEvaluator
- Inherits:
-
SelectorEvaluator
- Object
- SelectorEvaluator
- Checkoff::SectionSelectorEvaluator
- Defined in:
- lib/checkoff/internal/section_selector_evaluator.rb,
sig/checkoff.rbs
Overview
Evaluates section selectors against a section
Constant Summary collapse
- COMMON_FUNCTION_EVALUATORS =
(Checkoff::SelectorClasses::Common.constants.map do |const| Checkoff::SelectorClasses::Common.const_get(const) end - [Checkoff::SelectorClasses::Common::FunctionEvaluator]).freeze
- SECTION_FUNCTION_EVALUATORS =
(Checkoff::SelectorClasses::Section.constants.map do |const| Checkoff::SelectorClasses::Section.const_get(const) end - [Checkoff::SelectorClasses::Section::FunctionEvaluator]).freeze
- FUNCTION_EVALUATORS =
(COMMON_FUNCTION_EVALUATORS + SECTION_FUNCTION_EVALUATORS).freeze
Instance Attribute Summary collapse
-
#client ⇒ Asana::Client
readonly
sord warn - Asana::Client wasn't able to be resolved to a constant in this project.
- #custom_fields ⇒ Checkoff::CustomFields readonly
-
#item ⇒ Asana::Resources::Project
readonly
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project.
- #projects ⇒ Checkoff::Projects readonly
- #sections ⇒ Checkoff::Sections readonly
Instance Method Summary collapse
- #function_evaluators ⇒ Array<Class<Checkoff::SelectorClasses::Project::FunctionEvaluator>>
-
#initialize(section:, client:, projects: Checkoff::Projects.new(client:), sections: Checkoff::Sections.new(client:), custom_fields: Checkoff::CustomFields.new(client:), **_kwargs) ⇒ Object
constructor
sord warn - Asana::Resources::Section wasn't able to be resolved to a constant in this project sord warn - Asana::Client wasn't able to be resolved to a constant in this project @param
section. - #initializer_kwargs ⇒ Hash
Methods inherited from SelectorEvaluator
#evaluate, #evaluate_args, #try_this_evaluator
Constructor Details
#initialize(section:, client:, projects: Checkoff::Projects.new(client:), sections: Checkoff::Sections.new(client:), custom_fields: Checkoff::CustomFields.new(client:), **_kwargs) ⇒ Object
sord warn - Asana::Resources::Section wasn't able to be resolved to a constant in this project
sord warn - Asana::Client wasn't able to be resolved to a constant in this project
@param section
@param client
@param projects
@param sections
@param custom_fields
@param _kwargs
17 18 19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 17 def initialize(section:, client:, projects: Checkoff::Projects.new(client:), sections: Checkoff::Sections.new(client:), custom_fields: Checkoff::CustomFields.new(client:), **_kwargs) @item = section @client = client @projects = projects @sections = sections @custom_fields = custom_fields super() end |
Instance Attribute Details
#client ⇒ Asana::Client (readonly)
sord warn - Asana::Client wasn't able to be resolved to a constant in this project
65 66 67 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 65 def client @client end |
#custom_fields ⇒ Checkoff::CustomFields (readonly)
63 64 65 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 63 def custom_fields @custom_fields end |
#item ⇒ Asana::Resources::Project (readonly)
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
57 58 59 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 57 def item @item end |
#projects ⇒ Checkoff::Projects (readonly)
61 62 63 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 61 def projects @projects end |
#sections ⇒ Checkoff::Sections (readonly)
59 60 61 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 59 def sections @sections end |
Instance Method Details
#function_evaluators ⇒ Array<Class<Checkoff::SelectorClasses::Project::FunctionEvaluator>>
47 48 49 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 47 def function_evaluators FUNCTION_EVALUATORS end |
#initializer_kwargs ⇒ Hash
52 53 54 |
# File 'lib/checkoff/internal/section_selector_evaluator.rb', line 52 def initializer_kwargs { sections:, projects:, client:, custom_fields: } end |