Class: Checkoff::SelectorClasses::Common::AndFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::AndFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:and function
Constant Summary collapse
- FUNCTION_NAME =
:and
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(_resource, *args) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param
_resource. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #evaluate_arg?, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(_resource, *args) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
@param _resource
@param args
20 21 22 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 20 def evaluate(_resource, *args) args.all? { |arg| arg } end |
#matches? ⇒ Boolean
13 14 15 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 13 def matches? fn?(selector, FUNCTION_NAME) end |