Class: Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAllGidsPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Common::CustomFieldGidValueContainsAllGidsPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/common.rb,
sig/checkoff.rbs
Overview
:custom_field_gid_value_contains_all_gids? function
Constant Summary collapse
- FUNCTION_NAME =
:custom_field_gid_value_contains_all_gids?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
Instance Method Summary collapse
-
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project @param
resource. - #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Common::FunctionEvaluator
Instance Method Details
#evaluate(resource, custom_field_gid, custom_field_values_gids) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project
sord warn - Asana::Resources::Project wasn't able to be resolved to a constant in this project
@param resource
@param custom_field_gid
@param custom_field_values_gids
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 219 def evaluate(resource, custom_field_gid, custom_field_values_gids) actual_custom_field_values_gids = # @sg-ignore @custom_fields.resource_custom_field_values_gids_or_raise(resource, custom_field_gid) custom_field_values_gids.all? do |custom_field_value| # @sg-ignore actual_custom_field_values_gids.include?(custom_field_value) end end |
#evaluate_arg?(_index) ⇒ Boolean
211 212 213 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 211 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
207 208 209 |
# File 'lib/checkoff/internal/selector_classes/common.rb', line 207 def matches? fn?(selector, FUNCTION_NAME) end |