Class: Checkoff::SelectorClasses::Task::InSectionNamedPFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::InSectionNamedPFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:in_section_named? function
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task, section_name) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore.
-
#evaluate_arg?(_index) ⇒ Boolean
@param
_index. - #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task, section_name) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore
@param task
@param section_name
72 73 74 75 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 72 def evaluate(task, section_name) task_data = tasks.task_to_h(task) task_data.fetch('unwrapped').fetch('membership_by_section_name').keys.any?(section_name) end |
#evaluate_arg?(_index) ⇒ Boolean
@param _index
64 65 66 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 64 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
59 60 61 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 59 def matches? fn?(selector, :in_section_named?) end |