Class: Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator
- Inherits:
-
FunctionEvaluator
- Object
- FunctionEvaluator
- FunctionEvaluator
- Checkoff::SelectorClasses::Task::MilestonePFunctionEvaluator
- Defined in:
- lib/checkoff/internal/selector_classes/task.rb,
sig/checkoff.rbs
Overview
:milestone? function
Constant Summary collapse
- FUNCTION_NAME =
:milestone?
Instance Attribute Summary
Attributes inherited from FunctionEvaluator
#custom_fields, #selector, #tasks, #timelines
Instance Method Summary collapse
-
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore.
- #evaluate_arg?(_index) ⇒ Boolean
- #matches? ⇒ Boolean
Methods inherited from FunctionEvaluator
Methods inherited from FunctionEvaluator
#debug, #error, #finer, #fn?, #info, #log_level, #logger, #warn
Methods included from Logging
#debug, #error, #finer, #info, #log_level, #logger, #warn
Constructor Details
This class inherits a constructor from Checkoff::SelectorClasses::Task::FunctionEvaluator
Instance Method Details
#evaluate(task) ⇒ Boolean
sord warn - Asana::Resources::Task wasn't able to be resolved to a constant in this project @sg-ignore
@param task
366 367 368 369 370 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 366 def evaluate(task) raise 'Please add resource_subtype to extra_fields' if task.resource_subtype.nil? task.resource_subtype == 'milestone' end |
#evaluate_arg?(_index) ⇒ Boolean
358 359 360 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 358 def evaluate_arg?(_index) false end |
#matches? ⇒ Boolean
354 355 356 |
# File 'lib/checkoff/internal/selector_classes/task.rb', line 354 def matches? fn?(selector, FUNCTION_NAME) end |